# PyAlgoTrade
#
# Copyright 2011-2014 Gabriel Martin Becedillas Ruiz
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging


class Logger:
    def __init__(self, maxErrors=None):
        self.__maxErrors = maxErrors

    def info(self, msg):
        logging.info(msg)

    def error(self, msg):
        if self.__maxErrors is not None and self.__maxErrors > 0:
            self.__maxErrors -= 1
            logging.error(msg)

# logging.getLogger().setLevel(logging.DEBUG)
